# API documentation

Glowing pancake provides the following public API.

::::{eval-rst}
.. autofunction:: glopan.combine_pdfs
::::

::::{eval-rst}
.. autofunction:: glopan.delete_files
::::

::::{eval-rst}
.. autofunction:: glopan.docx_to_pdf
::::

::::{eval-rst}
.. autofunction:: glopan.many_ps_to_pdf
::::

::::{eval-rst}
.. autofunction:: glopan.pdf_convert
::::

::::{eval-rst}
.. autofunction:: glopan.pdf_to_emf
::::

::::{eval-rst}
.. autofunction:: glopan.pdf_to_png
::::

::::{eval-rst}
.. autofunction:: glopan.pdf_to_svg
::::

::::{eval-rst}
.. autofunction:: glopan.ps_to_pdf
::::

::::{eval-rst}
.. autofunction:: glopan.split_pdf
::::
